==> rivendell-1.5.0.zip: rivendell-1.5.0/rdcastmanager/rdcastmanager_fr.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>EditCast</name>
    <message>
        <source>Editing PodCast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Author E-Mail:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Category:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Link URL:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Source Text:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Source URL:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Comments URL:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Posted At:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cast Expires:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expires At:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Active</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Posting Status:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Episode
&amp;Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Air Date/Time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media Link:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListCasts</name>
    <message>
        <source>Podcast List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Post From
Car&amp;t/Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Post From
&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subscription
&amp;Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source></source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Origin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expires</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Link</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Uploading Audio...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Podcast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete this podcast?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deleting Podcast...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Internal Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to generate purge command!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remote Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to delete remote audio!
Continue deleting cast?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Never</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Only Show Unexpired Casts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Only Show Active Casts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Posting Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>RDCastManager - Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User: [Unknown]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Key Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Feed Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Casts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;View
Feed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> rivendell-2.2.0.zip: rivendell-2.2.0/rdcastmanager/rdcastmanager_fr.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>EditCast</name>
    <message>
        <source>Editing PodCast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Author E-Mail:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Category:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Link URL:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Source Text:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Source URL:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Comments URL:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Posted At:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cast Expires:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Active</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Posting Status:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Episode
&amp;Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Air Date/Time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media Link:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expires On:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListCasts</name>
    <message>
        <source>Podcast List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Post From
Car&amp;t/Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Post From
&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subscription
&amp;Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source></source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Origin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expires</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Link</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Uploading Audio...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Never</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Only Show Unexpired Casts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Only Show Active Casts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Posting Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Podcast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete this podcast?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deleting Podcast...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remote Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to delete remote audio!
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The server said: &quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue deleting cast?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>RDCastManager - Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User: [Unknown]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Key Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Feed Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Casts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;View
Feed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PickReportDates</name>
    <message>
        <source>Select Report Dates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Start Date:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;End Date:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Generate
Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
